import 'package:flutter/material.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:progamification/src/services/sas_token.service.dart';

class Rewards extends StatefulWidget {
  const Rewards({super.key});

  @override
  State<Rewards> createState() => _RewardsState();
}

class _RewardsState extends State<Rewards> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";

  @override
  initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    var userRewards = (leaderBoardController.userRewards['userRewards']);
    var rewardGroupNames = userRewards.keys.toList();

    return Column(
        children: rewardGroupNames
            .map((e) => getRewardsGroup(e, userRewards[e]))
            .toList()
            .cast<Widget>());
  }

  Widget getRewardsGroup(String title, List rewards) {
    return Column(
      children: [
        Align(
          alignment: Alignment.centerLeft,
          child: Padding(
            padding: const EdgeInsets.only(top: 16.0, bottom: 16.0, left: 8.0),
            child: Text(title,
                style: const TextStyle(
                    color: Colors.black,
                    fontWeight: FontWeight.w600,
                    fontSize: 20,
                    fontFamily: 'Roboto')),
          ),
        ),
        SizedBox(
            // height: 300,
            child: SingleChildScrollView(
                scrollDirection: Axis.vertical,
                child: Column(
                    children: rewards
                        .map((e) => getRewardItem(e['value'], e['sourceImgUrl'],
                            e['attained'] as bool))
                        .toList())))
      ],
    );
  }

  Widget getRewardItem(String title, String sourceImgUrl, bool isAttained) {
    return Align(
      alignment: Alignment.centerLeft,
      child: Row(children: [
        const SizedBox(height: 60),
        Opacity(
            opacity: isAttained ? 1.0 : 0.3,
            child: Container(
              width: 40,
              height: 40,
              margin: const EdgeInsets.only(left: 20.0, right: 2.0),
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                border: Border.all(
                  color: Colors.blue,
                  width: 2.5,
                ),
              ),
              child: ClipOval(
                child: Image.network(sourceImgUrl + sasToken,
                    fit: BoxFit.cover,
                    errorBuilder: (context, child, loadingProgress) => SizedBox(
                        width: 60.0,
                        height: 60.0,
                        child: Image.asset('assets/icons/no-reward.png',
                            package: 'progamification'))),
              ),
            )),
        Padding(
          padding: const EdgeInsets.all(8.0),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(title,
                  style: const TextStyle(
                      color: Colors.black,
                      fontWeight: FontWeight.w500,
                      fontSize: 16,
                      fontFamily: 'Roboto')),
              Text('Count :${isAttained ? '1' : '0'}',
                  style: const TextStyle(
                      color: Colors.grey,
                      fontWeight: FontWeight.w700,
                      fontSize: 14,
                      fontFamily: 'Roboto'))
            ],
          ),
        )
      ]),
    );
  }
}
